Learn R Programming

birdring (version 1.2)

coastpaleo: coordinates of the palearctic coastline

Description

coordinates of the palearctic coastline used by the function draw.map. The coordinates were downloaded from the sources indicated below and then cleaned by hand from too small details

Usage

data(coastpaleo)

Arguments

source

http://rimmer.ngdc.noaa.gov/mgg/coast/getcoast.html

References

http://rimmer.ngdc.noaa.gov/mgg/coast/getcoast.html

Examples

Run this code
data(coastpaleo)
head(coastpaleo)

Run the code above in your browser using DataLab