Learn R Programming

birdring (version 1.3)

scheme2country: Gives the country name from the scheme code

Description

Transforms the scheme codes into country name.

Usage

scheme2country(x)

Arguments

x

variable scheme from the data frame produced by read.EURING2000 or read.EURING2000plus

Value

a factor with levels coresponding to the country names

References

www.euring.org

See Also

codes2names

Examples

Run this code
# NOT RUN {
schemecode <- "HES"
scheme2country(schemecode)

# }

Run the code above in your browser using DataLab