Rdocumentation
powered by
Learn R Programming
birdring (version 1.2)
mercatorlat: gives the streching factor of the latitude to draw a mercator map
Description
this function is only used internally by the function draw.map
Usage
mercatorlat(x)
Arguments
x
latitude in decimal coordinates
Value
numeric: latitude to draw a mercator map
References
Rummler, H. (2002) Mercatorkarte und hyperbolische Geometrie. Elem. Math., 57, 168-173.
Examples
Run this code
mercatorlat(
41.6
)
Run the code above in your browser using
DataLab