powered by
Transforms the scheme codes into country name.
scheme2country(x)
variable scheme from the data frame produced by read.EURING2000 or read.EURING2000plus
a factor with levels coresponding to the country names
www.euring.org
codes2names
# NOT RUN { schemecode <- "HES" scheme2country(schemecode) # }
Run the code above in your browser using DataLab